<?php
/**
 * Element: Browsers
 * DEPRECATED!
 *
 * @package         NoNumber Framework
 * @version         14.11.6
 *
 * @author          Peter van Westen <peter@nonumber.nl>
 * @link            http://www.nonumber.nl
 * @copyright       Copyright © 2014 NoNumber All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

// For backwards compatibility
require_once __DIR__ . '/agents.php';

class JFormFieldNN_Browsers extends JFormFieldNN_Agents
{
}
